# Check localized WordPress releases

This package is for checking localized WordPress releases.

## How to use

1. Install this package
2. Run `python3 -m check_localized_wordpress_releases -o output.csv`
